(*
% This program defines the "pure" functions which return the value 
% of pursuing each of the possible housing options available at time LifePosn for 
% a given state. 
% FindBest requires several ambient variables to be defined.
*)

If[VerboseOutput == True,Print["Running FindBest.m"]];

FindBest[[LifePosn,ChoiceRentRent]] =
Block[{xt = #[[xtPos]],htStart = #[[htStartPos]],AggState=#[[AggStatePos]],DebtRatioWhenBoughtState=#[[DebtRatioWhenBoughtStatePos]],DebtRatioOnNewHomesState=#[[DebtRatioOnNewHomesStatePos]],EmpState=#[[EmpStatePos]]},
If[htStart>hmin,                      (* If they have positive housing assets,            *)
    (* then *)                        (*   then RentRent is not an option, so set c=z=s=0 *) 
       Print["htStart>hmin"];
       vt=-Infinity; ct=0;zt=0;st=0;,
    (* else hstart=0 *)               (*   else they have no housing assets, so proceed   *)
       If[xt > xmin,                  (*   If they have positive liquid assets            *)
           (* then *)                 (*     then choose optimal level of expenditures et *)
               MaxResults=	        (* %   to maximize utility u[] by minimizing        *)	
                 FindMinimum[	        (* %   the negative                                 *)		
                     -(u[(1-alpha)etRentRent
                        ,alpha etRentRent/(lambda[[DebtRatioOnNewHomesState]] q)]  (* Cobb-Douglas constant expenditure shares *)
                       +beta[[LifePosn+1]] EtVtp1[xt-etRentRent
                                   ,hmin
                                   ,AggState
                                   ,DebtRatioOnNewHomesState
                                   ,DebtRatioOnNewHomesState
                                   ,EmpState
                                   ,LifePosn]
                      ) (* End of utility minimand *)
                     ,{etRentRent,{xmin,xt}}];
               et = (etRentRent /. MaxResults[[2]]);
               If[Not[NumberQ[et]], (* then *) Print["RentRent failed."];Print[##];Interrupt[]]; 
               vt = -MaxResults[[1]];
               ct = (1-alpha) et;
               zt = alpha et/ (lambda[[DebtRatioOnNewHomesState]] q) ;
               st = xt-et;If[st < 0,Print["Error in RentBuy: st < 0"];Print[##];Interrupt[]];,
          (* % else xt=xmin=0 *) 	  (* else they have zero liquid assets so set ct, zt, and st to zero *)
               ct=zt=st=et=0; 
             vt=u[ct,zt] + beta[[LifePosn+1]] EtVtp1[xt-et,hmin,AggState,DebtRatioOnNewHomesState,DebtRatioOnNewHomesState,EmpState,LifePosn];
       ]; (* End If[xt > xmin] *)
];(* End If[htStart>hmin *)
{vt,ChoiceRentRent,ct,zt,hmin,st,DebtRatioOnNewHomesState}] &;



(* Comment out sections below for non-housing model.*)
(*


FindBest[[LifePosn,ChoiceRentBuy]] =
Block[{xt = #[[xtPos]],htStart = #[[htStartPos]],AggState=#[[AggStatePos]],DebtRatioWhenBoughtState=#[[DebtRatioWhenBoughtStatePos]],DebtRatioOnNewHomesState=#[[DebtRatioOnNewHomesStatePos]],EmpState=#[[EmpStatePos]]},
If[htStart>hmin,                          (* If housing assets exist,                 *)
  (* then *) ct=st=zt=0; vt=-Infinity,    (*   then RentBuy is not an option          *)
  (* else *)                              (*   else there are no housing assets,      *)
    htEnd = phi;                          (*     so buy a house                       *)
    zt = htEnd;                           (*     which yields housing services zt     *)
    HomePurchaseCosts = ((1-DebtRatioGrid[[DebtRatioOnNewHomesState]])+b) htEnd;               (* Down pmt     *)
    HomeCashFlowCosts = (m[[AggState]] DebtRatioGrid[[DebtRatioOnNewHomesState]] + n) htEnd;   (* Mort + maint *)
    HousingCosts = HomePurchaseCosts + HomeCashFlowCosts;
                                          (*     but requires down payment, mortgage, and maintenance spending *)
    maxs = xt - HousingCosts;             (*     If they consume 0 nonhousing resources, what is s ?           *)
    If[maxs >= smin,                      (*     If housing costs consume less than all of current assets      *)
    (* then *)                            (*       then choose optimal level of consumption expenditures       *)
      MaxResults= 
        FindMinimum[
          -(u[ctRentBuy,zt]
          +beta EtVtp1[xt-HousingCosts-ctRentBuy
                      ,htEnd
                      ,AggState
                      ,DebtRatioOnNewHomesState
                      ,DebtRatioOnNewHomesState
                      ,EmpState
                      ,LifePosn]
          ) (* End of minimand *)
        ,{ctRentBuy,{smin,maxs}}];
      ct = (ctRentBuy /. MaxResults[[2]]); If[Not[NumberQ[ct]], (* then *) Print["RentBuy failed"];Print[##];Interrupt[]]; 
      st = xt - HousingCosts - ct;         If[st < 0,Print["Error in RentBuy: st < 0"];Print[##];Interrupt[]];
      vt = -MaxResults[[1]];               
    ,
    (* % else ht=htmin=0 *)      (* else house purchase costs would consume more than all available assets *)
      ct=st=zt=htEnd=0;vt=GreatBadness  (* so make it very painful *)
      ];                               (* End If[maxs >= smin] *)
]; (* End if htStart > 0 *)
{vt,ChoiceRentBuy,ct,zt,htEnd,st,DebtRatioOnNewHomesState}] & ;


FindBest[[LifePosn,ChoiceSellRent]] =
Block[{xt = #[[xtPos]],htStart = #[[htStartPos]],AggState=#[[AggStatePos]],DebtRatioWhenBoughtState=#[[DebtRatioWhenBoughtStatePos]],DebtRatioOnNewHomesState=#[[DebtRatioOnNewHomesStatePos]],EmpState=#[[EmpStatePos]]},

If[htStart > 0,                                                             (* If they have a house to sell             *)
  (* then *)                                                                (*   then sell it                           *)
    w = xt + htStart * ((1-DebtRatioGrid[[DebtRatioWhenBoughtState]]) - b); (*   liquid resources = xt + saleproceeds   *)
    If[w >= xmin,                                                            (*   If they have positive resources        *)
      (* then *)                                                            (*     then decide how much to spend        *)
        MaxResults=
            FindMinimum[
              -(u[(1-alpha)etSellRent,alpha etSellRent/(lambda[[DebtRatioOnNewHomesState]] q)]  (* Cobb-Douglas spending shares *)
               +beta EtVtp1[w-etSellRent
                           ,hmin
                           ,AggState
                           ,DebtRatioOnNewHomesState
                           ,DebtRatioOnNewHomesState
                           ,EmpState
                           ,LifePosn]
               ) (* end of minimand *)
            ,{etSellRent,{xmin,w}}]; (* End of FindMinimum[] *)
        et  = (etSellRent /. MaxResults[[2]]);
        If[Not[NumberQ[et]], (* then *) Print["SellRent failed."];Print[##];Interrupt[]]; 
        ct = (1-alpha) et;
        zt = alpha et/(lambda[[DebtRatioOnNewHomesState]] q);
        st = w - et; If[st < 0,Print["Error in SellRent: st < 0"];Print[##];Interrupt[]];
        vt = -MaxResults[[1]];
        htEnd = hmin,
      (* else *)                                      (*    else they have no resources  *)
        ct=htEnd=zt=et=0;
        vt = u[0,0] + beta EtVtp1[smin,hmin,AggState,DebtRatioOnNewHomesState,DebtRatioOnNewHomesState,EmpState,LifePosn];
    ], (* End If[w>xmin] *)
  (* else *) vt = -Infinity; ct=zt=et=htEnd=st=0];        (* If you don't have a house, can't sell one *)
{vt,ChoiceSellRent,ct,zt,hmin,st,DebtRatioOnNewHomesState}] &;


FindBest[[LifePosn,ChoiceKeep]] = 
Block[{xt = #[[xtPos]],htStart = #[[htStartPos]],AggState=#[[AggStatePos]],DebtRatioWhenBoughtState=#[[DebtRatioWhenBoughtStatePos]],DebtRatioOnNewHomesState=#[[DebtRatioOnNewHomesStatePos]],EmpState=#[[EmpStatePos]]},
htEnd = htStart;
If[htStart>hmin,
  (* then *)
    zt = htEnd;
    HomeCashFlowCosts = (DebtRatioGrid[[DebtRatioWhenBoughtState]] m[[AggState]] + n)htEnd; (* Flow ownership costs          *)
    CashLeftAfterHousingCosts = xt - HomeCashFlowCosts;
    If[CashLeftAfterHousingCosts >= xmin, 
    (* then *) 
      MaxResults = 
        FindMinimum[
          -(u[ctKeep,zt]+
            beta EtVtp1[CashLeftAfterHousingCosts-ctKeep
                       ,htEnd
                       ,AggState
                       ,DebtRatioWhenBoughtState
                       ,DebtRatioOnNewHomesState
                       ,EmpState
                       ,LifePosn]
           ) (* End of minimand *)
        ,{ctKeep,{xmin,CashLeftAfterHousingCosts}}];
        ct = (ctKeep /. MaxResults[[2]]);    If[Not[NumberQ[ct]], (* then *) Print["Keep failed"];Print[##];Interrupt[]]; 
        vt = -MaxResults[[1]];		     If[Not[NumberQ[vt]], (* then *) Print["Keep failed"];Print[##];Interrupt[]]; 
        st = CashLeftAfterHousingCosts - ct; If[st < 0,Print["Error in Keep: st < 0"];Print[##];Interrupt[]];,

    (* else *)  (* No cash left after housing costs *)
        ct=zt=st=0; 
        vt=1000*u[ct,zt];
(*        vt=(u[ct,zt]+beta EtVtp1[0,htEnd,AggState,DebtRatioWhenBoughtState,DebtRatioOnNewHomesState,EmpState,LifePosn]) *)
    ];    (* Keeping the house would leave nothing for consumption *)
  ,(* else *)   ct=zt=st=0; vt=-Infinity];    (* Can't sell a house if you don't own one               *)
{vt,ChoiceKeep,ct,zt,htEnd,st,DebtRatioWhenBoughtState}] &;


FindBest[[LifePosn,ChoiceSellBuy]] =
Block[{xt = #[[xtPos]],htStart = #[[htStartPos]],AggState=#[[AggStatePos]],DebtRatioWhenBoughtState=#[[DebtRatioWhenBoughtStatePos]],DebtRatioOnNewHomesState=#[[DebtRatioOnNewHomesStatePos]],EmpState=#[[EmpStatePos]]},
If[htStart > hmin, 
  (* then *) 
    htEnd = phi;
    zt = htEnd;
    HomePurchaseCosts = (1-DebtRatioGrid[[DebtRatioOnNewHomesState]] + b)htEnd;
    HomeSaleProceeds  = (1-DebtRatioGrid[[DebtRatioWhenBoughtState]] - b)htStart;           (* Recoup downpmt of old         *)
    HomeCashFlowCosts = (DebtRatioGrid[[DebtRatioOnNewHomesState]] m[[AggState]] + n)htEnd; (* Flow ownership costs          *)
    CashLeftAfterSellBuy=xt+HomeSaleProceeds-HomePurchaseCosts-HomeCashFlowCosts;

    If[CashLeftAfterSellBuy >= xmin, 
      (* then *)
      MaxResults = 
         FindMinimum[
            -(u[ctSellBuy,zt]
            +beta EtVtp1[CashLeftAfterSellBuy-ctSellBuy
                       ,htEnd,AggState,DebtRatioOnNewHomesState,DebtRatioOnNewHomesState,EmpState,LifePosn]
             )
         ,{ctSellBuy,{xmin,CashLeftAfterSellBuy}}];
      ct =  (ctSellBuy /. MaxResults[[2]]);  If[Not[NumberQ[ct]], (* then *) Print["SellBuy failed"];Print[##];Interrupt[]]; 
      vt = -MaxResults[[1]];		     If[Not[NumberQ[vt]], (* then *) Print["SellBuy failed"];Print[##];Interrupt[]]; 
      st = CashLeftAfterSellBuy - ct;        If[st < 0,Print["Error in SellBuy: st < 0"];Print[##];Interrupt[]];
    ,(* else SellBuy would leave them with < min allowed assets *) 
      ct=st=htEnd=0;
      vt=GreatBadness;
(*      vt=(u[ct,zt]
          +beta EtVtp1[CashLeftAfterSellBuy-ct,htEnd,AggState,DebtRatioOnNewHomesState,DebtRatioOnNewHomesState,EmpState,LifePosn])*)
    ];         (* End If SellBuy would leave them with < min allowed assets *)
  ,(* else *) ct=st=htEnd=0;vt=-Infinity];             (* If no housing assets, then nothing to sell *)
If[ct < 0, (* then *) ct=st=htEnd=0;vt =GreatBadness];  (* If SellBuy consumes more than all of liquid assets, can't do it *)
{vt,ChoiceSellBuy,ct,zt,htEnd,st,DebtRatioOnNewHomesState}] &;

*)
