(* 
% find_crossings identifies points in the grid where the housing decision switches (e.g. from rent to buy),
% and augments the grid with points just below and just above the point where the consumer is indifferent
% between two housing choices, to more precisely define the switch point between housing choices
*)

Clear[ValueOfChoice];
ValueOfChoice[Choice_,xt_,ht_,AggState_,DebtRatioWhenBought_,DebtRatioOnNewHomes_,EmpState_,LifePosn_] := 
FindBest[[LifePosn,Choice]][{xt,ht,AggState,DebtRatioWhenBought,DebtRatioOnNewHomes,EmpState}];

<<FindBest.m;

DebtRatioWhenBoughtState = 1;
DebtRatioOnNewHomesState = 1;
xGridPointsToAdd  = {};
Do[
CurrentChoice =
  Round[
    Choicet[xgrid[[xgridpoint  ]],hgrid[[hgridpoint]],LoopOverAggStates,DebtRatioWhenBoughtState,DebtRatioOnNewHomesState,LoopOverEmpStates,LifePosn]];
LastChoice    =
  Round[
    Choicet[xgrid[[xgridpoint-1]],hgrid[[hgridpoint]],LoopOverAggStates,DebtRatioWhenBoughtState,DebtRatioOnNewHomesState,LoopOverEmpStates,LifePosn]];
If[(CurrentChoice != LastChoice),
  (* then *)
  Print["For (hgrid,AggState,EmpState) = ("<>ToString[hgridpoint]<>","<>ToString[LoopOverAggStates]<>","
        <>ToString[LoopOverEmpStates]<>"), "
        <>ToString[Round[50* xgrid[[xgridpoint-1]]]/50 //N]<>" < crossing <"
        <>ToString[Round[50* xgrid[[xgridpoint]]]/50 //N]];
  If[CurrentChoice==ChoiceKeep, 
    (* then *) HousingCosts = hgrid[[hgridpoint]] (m[[LoopOverAggStates]] DebtRatioGrid[[DebtRatioWhenBoughtState]] + n),
    (* else *) HousingCosts = (DebtRatioGrid[[DebtRatioOnNewHomesState]] m[[LoopOverAggStates]]+n)phi (* Mort+maint on new hse  *)
                              - (1-DebtRatioGrid[[DebtRatioWhenBoughtState]])hgrid[[hgridpoint]]      (* Recoup dnpmt of old hse*)
                              + (1-DebtRatioGrid[[DebtRatioOnNewHomesState]])phi                      (* Deduct downpmt of new  *)
                              +b(hgrid[[hgridpoint]]+phi);                                            (* Brokers' Fees          *)
    ]; (* End If[Choice...] *)
  xStartPoint = xgrid[[xgridpoint-1]];
(*  xStartPoint = Max[xgrid[[xgridpoint-1]],HousingCosts+.00001];*)
  xEndPoint   = xgrid[[xgridpoint]];
  SearchResults = FindRoot[
    ValueOfChoice[CurrentChoice,SearchOverx,hgrid[[hgridpoint]],LoopOverAggStates,DebtRatioWhenBoughtState,DebtRatioOnNewHomesState,LoopOverEmpStates,LifePosn][[1]] ==
    ValueOfChoice[LastChoice   ,SearchOverx,hgrid[[hgridpoint]],LoopOverAggStates,DebtRatioWhenBoughtState,DebtRatioOnNewHomesState,LoopOverEmpStates,LifePosn][[1]],
    {SearchOverx,{xStartPoint,xEndPoint}}];
    Print[SearchResults];
    xCrossPoint = (SearchOverx /. SearchResults);
    If[NumberQ[xCrossPoint] && xCrossPoint < xmax,
      (* then *)
      xGridPointsToAdd  = Append[xGridPointsToAdd ,xCrossPoint-.01];
      xGridPointsToAdd  = Append[xGridPointsToAdd ,xCrossPoint+.01];,
      (* else *) Print["Error.  Crossing point is either nonnumeric or > xmax."];Interrupt[];
    ] (* end If[NumberQ[xCrossPoint]] *)
  ] (* end If[ Choicet ...] *)
,{hgridpoint,1,Length[hgrid]}
,{LoopOverAggStates,NumOfAggStates}
,{xgridpoint,2,Length[xgrid]}
,{LoopOverEmpStates,NumOfEmpStates}
]

xgrid = Union[Sort[Round[50 Join[xgrid,xGridPointsToAdd]]/50 //N]];
<<tabulate_grids.m;



