(* 
% last_period solves for Vt in the last period of life for the given set of grid points and 
% for all possible states 
*)

Print["Solving Period "<>ToString[LifeLength]];

If[VerboseOutput == True,Print["Running last_period.m"]];

LifePosn = LifeLength;

(* 
% The file FindBest defines "pure" functions which return the optimal values of the control 
% variables for each possible choice of action (sell, rent, buy, keep, etc.).  The actual 
% optimal outcome will be the one which gives the greatest value among the feasible choices.
*)

<<FindBest.m;

(*
% VtbyChoice[[LifePosn]] will contain 6 lists of the values of the control variables given 
% optimal expenditure in each possible state, one list for each set of housing choices, i.e., 
% VtByChoice[[LifePosn,InStateGridPoint]] = {{values for choice 1},{values for choice 2}, etc}
*)

VtByChoice[[LifeLength]] = {};

(* 
% For the last period of life, loop through all 6 housing choices, using FindBest 
% to find the optimal values of the control variables for every possible state 
*)

Do[
Print["Calculating Results for Choice "<>ToString[LoopOverChoices]];
VtByChoice[[LifeLength]] = 
        Append[VtByChoice[[LifeLength]],Map[FindBest[[LifeLength,LoopOverChoices]],
        InStateGrid[[LifeLength]]]];
,{LoopOverChoices,NumOfChoices}];

(* 
% For each possible state VtVals picks the housing choice which has the highest value of Vt
% by choosing the one with the greatest first element of the list of control vars (which is Vt) 
*)

VtVals[[LifeLength]] = Map[MaxList,Transpose[VtByChoice[[LifeLength]]]];

(* 
% Set up the functions to interpolate between grid points
*)

<<make_interpolating.m;

