(* % Defines all of the baseline parameter values and 
   % converts them to per period rates where necessary *)

Print["Reading in the baseline parameter values."];

rho = 2.;             (* Coefficient of relative risk aversion                     *)
alpha = .25 //N;      (* Cobb-Douglas housing 'share'                              *)

YearsOfLife    = 80;  (* For finite-horizon version, life starts at age 20 and ends at 100 *)
PeriodsPerYear = 4;   (* 1 for annual, 4 for quarterly, 12 for monthly (AS IF!)   *)

LifeLength  = YearsOfLife*PeriodsPerYear;
FirstPeriod = 1;

Boom = 1;            (* Indicator that the aggregate state is a high-employment expansion *)
Bust = 2;            (* Indicator that the aggregate state is a contraction               *)
PostBust = 3;        (* Indicator that the aggregate state is just after a contraction    *)

(* % Each of the three aggregate states has a different growth rate of 
   % permanent income and degree of labor income uncertainty    *)
NumOfAggStates = 1;  
BoomGrowth     = 1.05;
BustGrowth     = 1.03;
PostBustGrowth = 1.05;

(* % Interest rates and growth rates are different for each agg state *)
(* Rannual = Gannual = Table[{},{NumOfAggStates}]; *)
Rannual = Gannual = Table[{},{NumOfAggStates}]; 

DebtRatioStateLow  = 1;			(* % Position number of low debt (baseline) state	      *)	
DebtRatioStateHigh = 2;			(* % Position number of high debt (liberalized) state	      *)	
DebtRatioGrid = {.8};                (* Ratio of debt to house value for new homes                 *)
DownPmtRatioGrid = 1-DebtRatioGrid;     (* Ratio of down payment to house value                       *)
NumOfDebtRatios = Length[DebtRatioGrid];(* % In our paper we have two debt ratios, one for a baseline 
					   % and one for after financial liberalization 	      *)	 

b     = .03;                            (* Brokerage fee                                              *)


(* betaannual  = .96;                   *)   (* Discount factor                                            *)
(* Gannual[[Boom]]       = BoomGrowth;  *)    (* Annual income growth rate in booms                         *)
(* Gannual[[Bust]]       = BustGrowth;  *)   (* Annual income growth rate in busts                    *)
(* Gannual[[PostBust]]   = BoomGrowth;  *)  (* Annual income growth rate in post-busts                *)


(* START OF NEW PART *)

ProbOfDeath = Table[{},{YearsOfLife}];
DiscountFactor = .96;  

(* Period 1 is age 21 *)

ProbOfDeath[[1]]=	0.00000	;
ProbOfDeath[[2]]=	0.00058	;
ProbOfDeath[[3]]=	0.00061	;
ProbOfDeath[[4]]=	0.00062	;
ProbOfDeath[[5]]=	0.00064	;
ProbOfDeath[[6]]=	0.00065	;
ProbOfDeath[[7]]=	0.00067	;
ProbOfDeath[[8]]=	0.00069	;
ProbOfDeath[[9]]=	0.00070	;
ProbOfDeath[[10]]=	0.00072	;
ProbOfDeath[[11]]=	0.00075	;
ProbOfDeath[[12]]=	0.00078	;
ProbOfDeath[[13]]=	0.00082	;
ProbOfDeath[[14]]=	0.00086	;
ProbOfDeath[[15]]=	0.00091	;
ProbOfDeath[[16]]=	0.00098	;
ProbOfDeath[[17]]=	0.00105	;
ProbOfDeath[[18]]=	0.00115	;
ProbOfDeath[[19]]=	0.00128	;
ProbOfDeath[[20]]=	0.00144	;
ProbOfDeath[[21]]=	0.00161	;
ProbOfDeath[[22]]=	0.00180	;
ProbOfDeath[[23]]=	0.00200	;
ProbOfDeath[[24]]=	0.00221	;
ProbOfDeath[[25]]=	0.00242	;
ProbOfDeath[[26]]=	0.00266	;
ProbOfDeath[[27]]=	0.00292	;
ProbOfDeath[[28]]=	0.00320	;
ProbOfDeath[[29]]=	0.00349	;
ProbOfDeath[[30]]=	0.00380	;
ProbOfDeath[[31]]=	0.00413	;
ProbOfDeath[[32]]=	0.00450	;
ProbOfDeath[[33]]=	0.00490	;
ProbOfDeath[[34]]=	0.00533	;
ProbOfDeath[[35]]=	0.00581	;
ProbOfDeath[[36]]=	0.00632	;
ProbOfDeath[[37]]=	0.00689	;
ProbOfDeath[[38]]=	0.00749	;
ProbOfDeath[[39]]=	0.00811	;
ProbOfDeath[[40]]=	0.00878	;
ProbOfDeath[[41]]=	0.00952	;
ProbOfDeath[[42]]=	0.01033	;
ProbOfDeath[[43]]=	0.01124	;
ProbOfDeath[[44]]=	0.01223	;
ProbOfDeath[[45]]=	0.01332	;
ProbOfDeath[[46]]=	0.01455	;
ProbOfDeath[[47]]=	0.01590	;
ProbOfDeath[[48]]=	0.01730	;
ProbOfDeath[[49]]=	0.01874	;
ProbOfDeath[[50]]=	0.02028	;
ProbOfDeath[[51]]=	0.02203	;
ProbOfDeath[[52]]=	0.02404	;
ProbOfDeath[[53]]=	0.02623	;
ProbOfDeath[[54]]=	0.02863	;
ProbOfDeath[[55]]=	0.03128	;
ProbOfDeath[[56]]=	0.03432	;
ProbOfDeath[[57]]=	0.03778	;
ProbOfDeath[[58]]=	0.04166	;
ProbOfDeath[[59]]=	0.04597	;
ProbOfDeath[[60]]=	0.05078	;
ProbOfDeath[[61]]=	0.05615	;
ProbOfDeath[[62]]=	0.06214	;
ProbOfDeath[[63]]=	0.06885	;
ProbOfDeath[[64]]=	0.07631	;
ProbOfDeath[[65]]=	0.08455	;
ProbOfDeath[[66]]=	0.09352	;
ProbOfDeath[[67]]=	0.10323	;
ProbOfDeath[[68]]=	0.11367	;
ProbOfDeath[[69]]=	0.12484	;
ProbOfDeath[[70]]=	0.13677	;
ProbOfDeath[[71]]=	0.14938	;
ProbOfDeath[[72]]=	0.16289	;
ProbOfDeath[[73]]=	0.17721	;
ProbOfDeath[[74]]=	0.19234	;
ProbOfDeath[[75]]=	0.20828	;
ProbOfDeath[[76]]=	0.22418	;
ProbOfDeath[[77]]=	0.23980	;
ProbOfDeath[[78]]=	0.25495	;
ProbOfDeath[[79]]=	0.26937	;
ProbOfDeath[[80]]=	0.28284	;

betaannual = Table[{},{LifeLength+1}];

Do[
betaannual[[(LoopOverYear-1)*PeriodsPerYear+LoopOverPeriodsOfYear]] = (1-ProbOfDeath[[LoopOverYear]]) DiscountFactor,   
{LoopOverPeriodsOfYear,PeriodsPerYear},{LoopOverYear,YearsOfLife}
];

(* In the last period of life, EtVtp1 is zero, so this value of beta doesn't matter, but can't be zero times zero *)
betaannual[[LifeLength+1]] = betaannual[[LifeLength]];

(* Note: age = year + 20 *)

NumOfLifeParts = 3;
StartOfLifePart1 = 1;   (* age 21 *)
StartOfLifePart2 = 81;   (* age 41/year 21 which is period 81 in quarterly data *)
StartOfLifePart3 = 181;  (* age 66/year 46 which is period 181 in quarterly data *)

(* Note: in part 3 you are retired until you die 35 years later at age 100 *)

StartOfLifePart={StartOfLifePart1,StartOfLifePart2,StartOfLifePart3};

BoomGrowthPart1=1.03;
BustGrowthPart1=1.02;
PostBustGrowthPart1=1.03;

BoomGrowthPart2=1.02;
BustGrowthPart2=1.01;
PostBustGrowthPart2=1.02;

BoomGrowthPart3=1.025
BustGrowthPart3=1.015
PostBustGrowthPart3=1.025;

Part1Growth={BoomGrowthPart1,BustGrowthPart1,PostBustGrowthPart1};
Part2Growth={BoomGrowthPart2,BustGrowthPart2,PostBustGrowthPart2};
Part3Growth={BoomGrowthPart3,BustGrowthPart3,PostBustGrowthPart3};

Gannual=Table[{},{LifeLength}];
Do[Gannual[[LoopOverLifePosn]]=Part1Growth,{LoopOverLifePosn,StartOfLifePart2-1}];
Do[Gannual[[LoopOverLifePosn]]=Part2Growth,{LoopOverLifePosn,StartOfLifePart2,StartOfLifePart3-1}];
Do[Gannual[[LoopOverLifePosn]]=Part3Growth,{LoopOverLifePosn,StartOfLifePart3,LifeLength}];

(* Note that the growth rate between period t and period t+1 is defined as G[[LifePosn+1]] *)


(* END OF NEW PART *)


Rannual[[Boom]]          = 1.02;        (* Annual interest rate in booms                              *)

(* Rannual[[Bust]]          = 1.02; *) 	(* Annual interest rate in busts                              *)
(* Rannual[[PostBust]]      = 1.02; *) 	(* Annual interest rate in post-busts                         *)

deltaannual              = .02;         (* Depreciation rate on houses                                *)
mannual = (Rannual-1)+deltaannual;      (* Relationship between after-tax mortgage rate and interest  *)
nannual = .05;                          (* Maintenance expenditures per year                          *)

NetDepreciation  = (1-DebtRatioGrid)deltaannual;       (* Depreciation of home value minus loan value *)

(* lambda is the flow cost of homeownership *)
lambdaannual =  (nannual + mannual)/Rannual;

InterpOrder = 1;                        (* % Order of interpolation in the interpolating functions; 1 is linear *)
phiannual = 3.;                         (* Size of new house relative to annual income                *)

(* Convert annual flow variables to per-period rates *)
G      = Gannual^(1/PeriodsPerYear);            (* Growth rates by aggregate state                        *)
R      = Rannual^(1/PeriodsPerYear);            (* Interest rates by aggregate state                      *) 
m      = (1+mannual)^(1/PeriodsPerYear)-1;      (* Mortgage payment                                       *)
n      = (1+nannual)^(1/PeriodsPerYear)-1;      (* Home maintenance expenditures                          *)
lambda = (1+lambdaannual)^(1/PeriodsPerYear)-1; (* Flow of housing services per unit of housing stock     *)
delta  = (1+deltaannual)^(1/PeriodsPerYear)-1;  (* Depreciation rate on housing                           *)
beta   = betaannual^(1/PeriodsPerYear);         (* Time preference discount factor                        *)
phi    = phiannual*PeriodsPerYear;              (* Size of new house relative to period income            *)
q      = 1.0;                                   (* Price of rental housing
compared to user cost of owned *)
DiscountR = 1.25^(1/PeriodsPerYear);  		(* Rate at which future income is discounted *)

(* Set up the limits and the grid density for the state variables *)

(* % cash-on-hand limits *)
(* make xmax  =  4. * PeriodsPerYear if doing annual *)
xmin  =  0.;
xmax  =  2. * PeriodsPerYear;
NumOfxSteps = 4;

(* % housing limits *)
hmin  = 0.0;
hmax  = 3. * PeriodsPerYear;
NumOfhSteps = 4;
hsupermax = 6*PeriodsPerYear;

(* % savings limits *)
smin  = 0.;
smax  = xmax;
NumOfsSteps = 4;

(* % The AggStateTransitionMatrix goves the probabilities of moving to 
   % each aggregate state tomorrow given a current aggregate state today
   % (based on empirical evidence - see table in paper *)
(* 
AggStateTransitionMatrix = {{.95,.05,0},{.05,.7,.25},{.25,.05,.7}};
*)

AggStateTransitionMatrix = {{1}};


LowMem = True;  (* Determines whether the low-memory version of the programs is run *)



