(*
% This program reads in the following packages:
% 	DiscreteMath'Permutations'
% 	Statistics'DataManipukation'
% It also sets up the routines that initialize the variables,
% and takes care of housekeeping preliminaries 
*)

PeriodsToKeep={1,2,3,5,10,20};
KeepEveryNthPeriod=100;

<<Graphics`Legend`

Print["Setting up the background routines"];

(* % Defines the period utility function - CRRA utility, adding epsilon 
   % so that u(0,0) is not -infinity *)
ClearAll[u];
u[c_,z_] := If[c >= 0 && z >= 0,
               (* then *) ((((c+(1-alpha)epsilon)^(1-alpha))((z+alpha epsilon)^alpha))^(1-rho))/(1-rho),
               (* else *) (((((1-alpha)epsilon)^(1-alpha))((alpha epsilon)^alpha))^(1-rho))/(1-rho)];

(* % Define the probability of moving to FutureState next period if in CurrentState today *)
AggStateProb[CurrentState_,FutureState_] := AggStateTransitionMatrix[[CurrentState,FutureState]];

(* % Finds the position number of the list item with greatest first element *)
ClearAll[MaxPos]; 
MaxPos[list_] := Block[{MaxSoFar = 1}, 
   Do[If[list[[ListPos,1]]>list[[MaxSoFar,1]],MaxSoFar=ListPos],{ListPos,Length[list]}];MaxSoFar];

(* % Returns the maximum value in a list *)
ClearAll[MaxList]; 
MaxList[list_] := list[[MaxPos[list]]];

(* % Adds a value corresponding to each set of values in the state grid *)
ClearAll[AddOutcome]; 
AddOutcome[StateGrid_,ValuesToAdd_] := Transpose[Join[Transpose[StateGrid],{ValuesToAdd}]];

(* % Saves values for all variables *)
ClearAll[SaveModel];
SaveModel[filename_] := Block[{},
Print["Attempting to save ..."];
DeleteFile[filename];
Save[filename
(* ,EtVtp1Raw *)
(* ,EtVtp1 ,EtVtp1InterpFunc *)
,Vt     ,VtInterpFunc
,Choicet,ChoicetInterpFunc
,ctOpt  ,ctOptInterpFunc
,ztOpt  ,ztOptInterpFunc
,htOpt  ,htOptInterpFunc
,stOpt  ,stOptInterpFunc
,LifePosn,LifeLength,rho,alpha,YearsOfLife,PeriodsPerYear
,b,betaannual,Gannual,Rannual,mannual,lambdaannual,phiannual
,G,R,m,n,lambda,beta,phi,q,xmin,xmax,xstep,hmin,hmax,hsupermax,hstep,smin,smax,sstep
,InterpOrder,EarliestPeriodSolved
,epVals,NumOfetVals
,InStateGridBaseline
,OutStateGridBaseline
,DebtRatioGrid
,xgrid,sgrid,hgrid
]];

(* % Saves values for a subset of variables *)
SaveModelSmall[filename_] := Block[{},
Print["Attempting to save solved model small..."];
DeleteFile[filename];
Do[
VtVals[[LoopOverLifePosn]] = VtByChoice[[LoopOverLifePosn]]  
=ctOptInterpData[[LoopOverLifePosn]] =ztOptInterpData[[LoopOverLifePosn]] 
=htOptInterpData[[LoopOverLifePosn]] =stOptInterpData[[LoopOverLifePosn]] 
=EtVtp1InterpData[[LoopOverLifePosn]] =ChoicetInterpData[[LoopOverLifePosn]] 
=VtInterpData[[LoopOverLifePosn]] 
(*
=ctOptInterpFunc[[LoopOverLifePosn]] =ztOptInterpFunc[[LoopOverLifePosn]] 
=htOptInterpFunc[[LoopOverLifePosn]] =stOptInterpFunc[[LoopOverLifePosn]] 
=EtVtp1InterpFunc[[LoopOverLifePosn]] =ChoicetInterpFunc[[LoopOverLifePosn]] 
=VtInterpFunc[[LoopOverLifePosn]] = {};
*)
,{LoopOverLifePosn,EarliestPeriodSolved+2,LifeLength}];
Save[filename
,EtVtp1Raw
,EtVtp1 ,EtVtp1InterpFunc
,Vt     ,VtInterpFunc
,Choicet,ChoicetInterpFunc
,ctOpt  ,ctOptInterpFunc
,ztOpt  ,ztOptInterpFunc
,htOpt  ,htOptInterpFunc
,stOpt  ,stOptInterpFunc
,LifePosn,LifeLength,rho,alpha,YearsOfLife,PeriodsPerYear
,b,betaannual,Gannual,Rannual,mannual,lambdaannual,phiannual
,G,R,m,n,lambda,beta,phi,q,xmin,xmax,xstep,hmin,hmax,hsupermax,hstep,smin,smax,sstep
,InterpOrder,EarliestPeriodSolved
,epVals,NumOfetVals
,InStateGridBaseline
,OutStateGridBaseline
,DebtRatioGrid
,xgrid,sgrid,hgrid
];
];

Print["Initializing the background variables"];

(* % Assign codes for the housing choices they can make in each period *)
(* NumOfChoices = 5; *)
NumOfChoices = 1;
ChoiceRentRent = 1;
ChoiceRentBuy  = 2;
ChoiceSellRent = 3;
ChoiceKeep     = 4;
ChoiceSellBuy  = 5;

(* % Assign position numbers to each state variable in the input and output lists *)
xtPos=stPos = 1;
htStartPos  = 2;
htEndPos    = 2;
AggStatePos = 3;
DebtRatioWhenBoughtStatePos= 4;
DebtRatioOnNewHomesStatePos= 5;
EmpStatePos = 6;
LifePosnPos = 7;

(* % Assign position numbers to each control variable in the output lists *)
VtPos      = 1;
ChoicetPos = 2;
ctPos      = 3;
ztPos      = 4;
htEndPosOut= 5;
stPosOut   = 6;
DebtRatioWhenBoughtPosOut = 7;

(* % Add epsilon to consumption and housing in utility function 
   % so that u(0,0) is not -Infinity *)
(* epsilon=.1;  *)
epsilon=.01;

GreatBadness = 1000*u[0,0];

(* % Verbose output will display various status message throughout the 
   % execution of the program *)
VerboseOutput = True;

(* % Read in necessary packages *)
<<DiscreteMath`Permutations`
<<Statistics`DataManipulation`
<<Statistics`DescriptiveStatistics`
(*<<histogram.m*)

(* % Finds the eigenvector that represents the steady-state distribution of 
% outcomes for a given probability transition matrix.  It will be the 
% eigenvector that corresponds to an eigenvalue of 1. *)
Clear[FindRightEigenVec];
FindRightEigenVec[TransitionMatrix_] := Block[{},RightEigenVec = -1;
{EigenVals,EigenVecs} = Eigensystem[TransitionMatrix];
Do[
If[EigenVals[[i]] == 1.,
    (* then *) RightEigenVec = EigenVecs[[i]]];
,{i,Length[EigenVals]}];
If[RightEigenVec == -1, 
  (* then *) Print["No suitable Eigenvectors exist."]];
RightEigenVec / Last[CumulativeSums[RightEigenVec]]
];


(* % Sets up easy-to-use routine for doing linear regressions *)
ClearAll[MyReg];
MyReg[Depvar_,IndepVarNames_] := Block[{},
Outstuff = 
  Regress[
    Transpose[Join[ToExpression[IndepVarNames],{Depvar}]]
,ToExpression[Table["x"<>ToString[i],{i,Length[IndepVarNames]}]]
,ToExpression[Table["x"<>ToString[i],{i,Length[IndepVarNames]}]]
,BasisNames->Join[{"Constant"},IndepVarNames]
,RegressionReport->{ParameterTable,AdjustedRSquared,DurbinWatsonD,PredictedResponse}];
Print[ParameterTable /. Outstuff];
Print[""];
Print["R-Bar:         ",AdjustedRSquared /. Outstuff];
Print["Durbin-Watson: ",DurbinWatsonD   /. Outstuff];
Return[Outstuff]];

(* % Performs linear regressions using only a given range of values *)
ClearAll[MyRegRange];
MyRegRange[Depvar_,IndepVarNames_,RangeToUse_] := Block[{},
SetOptions[$Output,PageWidth->Infinity];
Outstuff = 
  Regress[
    Take[Transpose[Join[ToExpression[IndepVarNames],{Depvar}]],RangeToUse]
,ToExpression[Table["x"<>ToString[i],{i,Length[IndepVarNames]}]]
,ToExpression[Table["x"<>ToString[i],{i,Length[IndepVarNames]}]]
,BasisNames->Join[{"Constant"},IndepVarNames]
,RegressionReport->{ParameterTable,AdjustedRSquared,DurbinWatsonD,PredictedResponse}];
Print[ParameterTable /. Outstuff];
Print[""];
Print["R-Bar:         ",AdjustedRSquared /. Outstuff];
Print["Durbin-Watson: ",DurbinWatsonD   /. Outstuff];
SetOptions[$Output,PageWidth->132];
Return[Outstuff]];


(* % Finds the position number of the first element in listname 
   % whose value is greater than the value of comparison *)
FirstElementGreaterThan[listname_,comparison_] := 
Block[{ListLength=Length[listname]},
For[CurrentElement=1,
comparison>listname[[CurrentElement]] && CurrentElement<ListLength,CurrentElement++];
CurrentElement];

(* % Generates a new list of the values in list lagged one period *)
Lagged[list_] := Join[{0},Table[list[[i-1]],{i,2,Length[list]}]];

(* % Finds all position numbers of the elements in list 
   % whose value is greater than the value of GreaterThan 
   % and less than the value of LessThan *)
PositionsGreaterLess[list_,GreaterThan_,LessThan_] := Block[{},
building = {};
Do[
If[list[[i]] > GreaterThan && list[[i]] < LessThan,building = Append[building,i]]
,{i,Length[list]}];
building]

ClearAll[PlotRecessions];
PlotRecessions[Scale_,Height_,StartPeriod_,EndPeriod_] := Block[{},
(* First find beginnings and ends of recessions *)
RecessionPeriods = {};
Counter = StartPeriod;
While[Counter <= EndPeriod,
  (* If the current period is a recession *)
  If[aggstate[[Counter]] == Bust,
    (* then find the end of the recession *)
      StartOfRecession = Counter;
      While[aggstate[[Counter]] == Bust,Counter++];
      LastPeriodOfRecession = Counter-1;
      RecessionPeriods = Append[RecessionPeriods,{StartOfRecession-.5,LastPeriodOfRecession+.5}],
    (* else keep looking *)
      Counter++
  ] (* End if *)
];

Table[{GrayLevel[.35],Rectangle[{RecessionPeriods[[i,1]],Height},{RecessionPeriods[[i,2]],Height+Scale}]}
,{i,Length[RecessionPeriods]}]
];

ClearAll[PlotRecovery];
PlotRecovery[Scale_,Height_,StartPeriod_,EndPeriod_] := Block[{},
(* First find beginnings and ends of Recoveries *)
RecoveryPeriods = {};
Counter = StartPeriod;
While[Counter <= EndPeriod,
  (* If the current period is a Recovery *)
  If[aggstate[[Counter]] == PostBust,
    (* then find the end of the Recovery *)
      StartOfRecovery = Counter;
      While[aggstate[[Counter]] == PostBust,Counter++];
      LastPeriodOfRecovery = Counter-1;
      RecoveryPeriods = Append[RecoveryPeriods,{StartOfRecovery-.5,LastPeriodOfRecovery+.5}],
    (* else keep looking *)
      Counter++
  ] (* End if *)
];

Table[{GrayLevel[.55],Rectangle[{RecoveryPeriods[[i,1]],Height},{RecoveryPeriods[[i,2]],Height+Scale}]}
,{i,Length[RecoveryPeriods]}]
];
