
(* 
% simulation_routines defines the functions used in doing simulations
% The following functions are defined:
%
%	ClearPeriodsFromTo
%	SetupSimulationVars
% 	Simulate
%	KeepSimulatingFromTo
%	LP	
%	LPSeriesFromTo

Variables to keep track of:

xtSims  - cash on hand
stSims  - savings/liquid assets 
htSims  - housing stock owned
ctSims  - consumption of nonhousing goods
ztSims  - consumption of housing services
dtSims  - debt
DebtRatioWhenBought - what was the size of the debt ratio when the current house was bought
aggstate - aggregate state

*)

ClearPeriodsFromTo[PeriodFrom_,PeriodTo_] := Block[{},
Do[
      xtSims[[LoopOverClearedObs]]  = 0;
      stSims[[LoopOverClearedObs]]  = 0;
      savSims[[LoopOverClearedObs]] = 0;
      htSims[[LoopOverClearedObs]]  = 0;
      ctSims[[LoopOverClearedObs]]  = 0;
      ztSims[[LoopOverClearedObs]]  = 0;
      dtSims[[LoopOverClearedObs]]  = 0;
      XtSims[[LoopOverClearedObs]]  = 0;
      StSims[[LoopOverClearedObs]]  = 0;
      SavSims[[LoopOverClearedObs]] = 0;
      HtSims[[LoopOverClearedObs]]  = 0;
      CtSims[[LoopOverClearedObs]]  = 0;
      ZtSims[[LoopOverClearedObs]]  = 0;
      DtSims[[LoopOverClearedObs]]  = 0;
      etDraws[[LoopOverClearedObs]] = 0;
      epDraws[[LoopOverClearedObs]] = 0;
      DebtRatioWhenBought[[LoopOverClearedObs]]   = 0;
      etVarsPopulation[[LoopOverClearedObs]]      = 0;
      epVarsPopulation[[LoopOverClearedObs]]      = 0;
      PermanentIncomeSims[[LoopOverClearedObs]]   = 0;
      ChoicetSims[[LoopOverClearedObs]]           = 0;
      StateVars[[LoopOverClearedObs]]             = 0;
      PeriodsSinceLastHomePurchase[[LoopOverClearedObs]] = 0;
,{LoopOverClearedObs,PeriodFrom,PeriodTo}
];
];

SetupSimulationVars := Block[{},

EmploymentStatus = StateVars = PeriodsSinceLastHomePurchase 
= PermanentIncomeSims = DebtRatioWhenBought = epVarsPopulation = etVarsPopulation = epDraws = etDraws 
= savSims = dtSims = stSims = ctSims = ztSims = xtSims = htSims 
= SavSims = DtSims = StSims = CtSims = ZtSims = XtSims = HtSims 
= ChoicetSims = Table[{},{LifeLength}];

HomesBoughtPerCapita =
HomesSoldPerCapita   = 
UnemploymentRate = 
PeriodsSinceLastHomePurchaseMean =
ChoicetRentRent  = 
ChoicetRentBuy   = 
ChoicetSellRent  = 
ChoicetKeep      = 
ChoicetSellBuy   = Table[0,{LifeLength}];

Income =
AnnuityIncome = 
IncomeOverAnnuityIncome = 
ExpectedJobLossRisk =
EmploymentStatusCounts =
PermanentIncomeMean = 
DebtRatioWhenBoughtMean =
xtSimsMean = 
savSimsMean=
stSimsMean = 
htSimsMean = 
ctSimsMean = 
ztSimsMean = 
dtSimsMean = 
XtSimsMean = 
SavSimsMean=
StSimsMean = 
HtSimsMean = 
CtSimsMean = 
ZtSimsMean = 
DtSimsMean = 
etDrawsMean=
epDrawsMean= Table[{},{LifeLength}];

];


(*
% Set up the initial period, then use KeepSimulatingFromTo to iteratively keep simulating periods
% from 2 to NumOfPeriods 
*)

ClearAll[Simulate];
Simulate[StartWealth_,StartHousing_,NumOfPeriods_,NumOfPeople_,AggStateFile_:"inputs/aggstate_default.m"] := 
Block[{},

aggstate = Table[Boom,{LifeLength}]; (* default is perpetual expansion                 *)
DebtRatioStateList = aggstate;

Get[AggStateFile];                (* Get the sequence of aggregate state indicators *)

SetupSimulationVars;

(* Set up the initial period *)

FirstPeriod = 1;
SavSims[[FirstPeriod]]  = savSims[[FirstPeriod]]  = Table[0            ,{i,NumOfPeople}];
XtSims[[FirstPeriod]]   = xtSims[[FirstPeriod]]   = Table[StartWealth+1,{i,NumOfPeople}];
StSims[[FirstPeriod]]   = stSims[[FirstPeriod]]   = Table[StartWealth  ,{i,NumOfPeople}];

(* HtSims[[FirstPeriod]]   = htSims[[FirstPeriod]]   = Table[i
,{i,StartHousing,phi,(phi-StartHousing)/(NumOfPeople-1)}]; *)

HtSims[[FirstPeriod]]   = htSims[[FirstPeriod]]   = Table[0,{i,NumOfPeople}]; 

CtSims[[FirstPeriod]]   = ctSims[[FirstPeriod]]   = Table[(1-alpha)    ,{i,NumOfPeople}];
ZtSims[[FirstPeriod]]   = ztSims[[FirstPeriod]]   = Table[alpha        ,{i,NumOfPeople}];
DtSims[[FirstPeriod]]   = dtSims[[FirstPeriod]]   = htSims[[FirstPeriod]] DebtRatioGrid[[aggstate[[FirstPeriod]]]];
etDraws[[FirstPeriod]]  = Table[1            ,{i,NumOfPeople}];
epDraws[[FirstPeriod]]  = Table[1            ,{i,NumOfPeople}];
PermanentIncomeSims[[FirstPeriod]]          = Table[1,{i,NumOfPeople}];
PeriodsSinceLastHomePurchase[[FirstPeriod]] = Table[0,{i,NumOfPeople}];
EmploymentStatus[[FirstPeriod]]             = Table[1,{i,NumOfPeople}];

DebtRatioWhenBought[[FirstPeriod]] = Table[DebtRatioStateList[[FirstPeriod]],{NumOfPeople}];

ChoicetRentRent[[FirstPeriod]] = 
ChoicetRentBuy[[FirstPeriod]]  = 
ChoicetSellRent[[FirstPeriod]] = 
ChoicetKeep[[FirstPeriod]]     = 
ChoicetSellBuy[[FirstPeriod]]  = 0;

EmploymentStatusCounts[[FirstPeriod]] = {NumOfPeople,0,0};
PeriodsSinceLastHomePurchaseMean[[FirstPeriod]] = 0;
xtSimsMean[[FirstPeriod]]  = Mean[xtSims[[FirstPeriod]]];
savSimsMean[[FirstPeriod]] = Mean[savSims[[FirstPeriod]]];
stSimsMean[[FirstPeriod]]  = Mean[stSims[[FirstPeriod]]];
htSimsMean[[FirstPeriod]]  = Mean[htSims[[FirstPeriod]]];
ctSimsMean[[FirstPeriod]]  = Mean[ctSims[[FirstPeriod]]];
ztSimsMean[[FirstPeriod]]  = Mean[ztSims[[FirstPeriod]]];
dtSimsMean[[FirstPeriod]]  = Mean[dtSims[[FirstPeriod]]];
XtSimsMean[[FirstPeriod]]  = Mean[XtSims[[FirstPeriod]]];
SavSimsMean[[FirstPeriod]] = Mean[SavSims[[FirstPeriod]]];
StSimsMean[[FirstPeriod]]  = Mean[StSims[[FirstPeriod]]];
HtSimsMean[[FirstPeriod]]  = Mean[HtSims[[FirstPeriod]]];
CtSimsMean[[FirstPeriod]]  = Mean[CtSims[[FirstPeriod]]];
ZtSimsMean[[FirstPeriod]]  = Mean[ZtSims[[FirstPeriod]]];
DtSimsMean[[FirstPeriod]]  = Mean[DtSims[[FirstPeriod]]];
etDrawsMean[[FirstPeriod]] = Mean[etDraws[[FirstPeriod]]];
epDrawsMean[[FirstPeriod]] = Mean[epDraws[[FirstPeriod]]];
DebtRatioWhenBoughtMean[[FirstPeriod]]   = DebtRatioStateList[[FirstPeriod]];
PermanentIncomeMean[[FirstPeriod]]       = 1;
Income[[FirstPeriod]]                    = AggEmpState[FirstPeriod] . TransitoryIncomeByAggEmpState;
AnnuityIncome[[FirstPeriod]]
  = AggEmpState[FirstPeriod] . AnnuityIncomeByAggEmpState[[StartOfLifePart1]];
IncomeOverAnnuityIncome[[FirstPeriod]]   = Income[[FirstPeriod]] / AnnuityIncome[[FirstPeriod]];
ExpectedJobLossRisk[[FirstPeriod]]       = ExpectedJobLossRiskByAggEmpState[FirstPeriod];
UnemploymentRate[[FirstPeriod]]          = 1- EmploymentStatusCounts[[FirstPeriod,EmpStateEmployed]]/NumOfPeople //N;


KeepSimulatingFromTo[2,NumOfPeriods];
]; (* End of Simulate[] *)


KeepSimulatingFromTo[StartPeriod_,EndPeriod_] := Block[{},
NumOfPeople = Length[stSims[[StartPeriod-1]]];

(* 
% Generate the randomly drawn employment status, transitory income shock, and permanent 
% income shock for all people in the simulation in the given period
*)

Do[

Print["Starting Period "<>ToString[LoopOverPeriods]];

(* % 1 - Generate the random employment draw *)

EmploymentPopulation = Table[i/(NumOfPeople+1) //N,{i,NumOfPeople}];
EmploymentDraws = EmploymentPopulation[[RandomPermutation[NumOfPeople]]];

EmploymentStatus[[LoopOverPeriods]] = 
  Table[
    CumEmpStateNext[
       aggstate[[LoopOverPeriods]]
      ,EmploymentStatus[[LoopOverPeriods-1,LoopOverPeople]]
      ,EmploymentDraws[[LoopOverPeople]]]
  ,{LoopOverPeople,NumOfPeople}];

(* % EmploymentStatusCounts calculates the number of people with each type of employment status (1,2,3) *)

EmploymentStatusCounts[[LoopOverPeriods]] =
   {Length[Position[EmploymentStatus[[LoopOverPeriods]],1]],
    Length[Position[EmploymentStatus[[LoopOverPeriods]],2]],
    Length[Position[EmploymentStatus[[LoopOverPeriods]],3]]};

(* % 2 - Generate the random transitory income shock draw *)

etDraws[[LoopOverPeriods]] = 
  Table[
    etVals[[
      aggstate[[LoopOverPeriods]],
      EmploymentStatus[[LoopOverPeriods,LoopOverPeople]],
      FirstElementGreaterThan[
        etProbCum[[aggstate[[LoopOverPeriods]],EmploymentStatus[[LoopOverPeriods,LoopOverPeople]]]],
        Random[]]]]                  (* End FirstElementGreaterThan *)
  ,{LoopOverPeople,NumOfPeople}];    (* End Table[] *)

(* % 3 - Generate the random permanent income shock draw *)

epDraws[[LoopOverPeriods]] = 
  Table[
    epVals[[
      aggstate[[LoopOverPeriods]],
      EmploymentStatus[[LoopOverPeriods,LoopOverPeople]],
      FirstElementGreaterThan[
        epProbCum[[aggstate[[LoopOverPeriods]],EmploymentStatus[[LoopOverPeriods,LoopOverPeople]]]],
        Random[]]]]                  (* End FirstElementGreaterThan *)
  ,{LoopOverPeople,NumOfPeople}];    (* End Table[] *)

(* % Calculate permanent income *)

PermanentIncomeSims[[LoopOverPeriods]] = epDraws[[LoopOverPeriods]] * G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] *PermanentIncomeSims[[LoopOverPeriods-1]];

(* Calculate the new level of cash-on-hand *)

xtSims[[LoopOverPeriods]]=(R[[aggstate[[LoopOverPeriods]]]]/(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods]]))
				*stSims[[LoopOverPeriods-1]]
		                +etDraws[[LoopOverPeriods]];
(* 
Print["G="<>ToString[G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]]]];
Print["xtSims= "<>ToString[xtSims[[LoopOverPeriods]]]];
*)

XtSims[[LoopOverPeriods]]=xtSims[[LoopOverPeriods]] PermanentIncomeSims[[LoopOverPeriods]];

(* Create three tables with length matching the population size containing 
   variables indicating the current aggregate state, the current maximum
   leverage on mortgage loans, and the current period of life *)

aggstateTable = Table[aggstate[[LoopOverPeriods]]                           ,{NumOfPeople}];
DebtRatioTable= Table[DebtRatioStateList[[LoopOverPeriods]]                 ,{NumOfPeople}];
LifePosnTable = Table[LoopOverPeriods                                       ,{NumOfPeople}];

(* Fill in the as-yet-undetermined variables with zeros *)
PeriodsSinceLastHomePurchase[[LoopOverPeriods]] =
ctSims[[LoopOverPeriods]]              =
ztSims[[LoopOverPeriods]]              =
dtSims[[LoopOverPeriods]]              =
htSims[[LoopOverPeriods]]              = 
stSims[[LoopOverPeriods]]              = 
savSims[[LoopOverPeriods]]             =
ctSims[[LoopOverPeriods]]              =
ztSims[[LoopOverPeriods]]              =
dtSims[[LoopOverPeriods]]              =
htSims[[LoopOverPeriods]]              = 
stSims[[LoopOverPeriods]]              = 
savSims[[LoopOverPeriods]]             =
DebtRatioWhenBought[[LoopOverPeriods]] = 
RentalCosts                            = 
HomeSaleProceeds                       =
HomePurchCosts                         = 
HomeCarryingCosts                      = Table[0,{NumOfPeople}];

(* Create a list of state variable values for each household *)

StateVars[[LoopOverPeriods]]
          = Transpose[{xtSims[[LoopOverPeriods]]
                      ,htSims[[LoopOverPeriods-1]](1-delta)/(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods]])
                      ,aggstateTable
                      ,DebtRatioWhenBought[[LoopOverPeriods-1]]
                      ,DebtRatioTable
                      ,EmploymentStatus[[LoopOverPeriods]]
                      ,LifePosnTable}];

(* Figure out what each household will do in terms of its housing choice    *)

ChoicetSims[[LoopOverPeriods]] = Round[Map[Choicet,StateVars[[LoopOverPeriods]]]]; 

(* Calculate optimal housing services       *)

ztSims[[LoopOverPeriods]]      = Map[ztOpt,StateVars[[LoopOverPeriods]]];          

(* Calculate optimal nonhousing consumption *)

ctSims[[LoopOverPeriods]]      = Map[ctOpt,StateVars[[LoopOverPeriods]]];          

(* % Calculate levels from the ratio to permanent income *)

ZtSims[[LoopOverPeriods]]      = PermanentIncomeSims[[LoopOverPeriods]] ztSims[[LoopOverPeriods]];
CtSims[[LoopOverPeriods]]      = PermanentIncomeSims[[LoopOverPeriods]] ctSims[[LoopOverPeriods]];

(* % Reset the counts used to calculate the fraction of people making each housing choice *)

ChoicetRentRent[[LoopOverPeriods]] = ChoicetRentBuy[[LoopOverPeriods]] = ChoicetSellRent[[LoopOverPeriods]] =
ChoicetKeep[[LoopOverPeriods]] = ChoicetSellBuy[[LoopOverPeriods]] = 0;

(* 
% Loop over the individuals being simulated, and for each individual, calculate the home-related 
% variables based on their ChoicetSims 
*) 

Do[ 
  If[ChoicetSims[[LoopOverPeriods,LoopOverPeople]] == ChoiceRentRent,
    htSims[[LoopOverPeriods,LoopOverPeople]] = hmin;
    HomeSaleProceeds[[LoopOverPeople]]       = 0;
    HomePurchCosts[[LoopOverPeople]]         = 0; 
    RentalCosts[[LoopOverPeople]]            = q lambda[[DebtRatioStateList[[LoopOverPeriods]]]] 
                                               *ztSims[[LoopOverPeriods,LoopOverPeople]];
(*  Print["RentalCosts = "<>ToString[RentalCosts]]; *)
    DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]] = DebtRatioStateList[[LoopOverPeriods]];
    dtSims[[LoopOverPeriods,LoopOverPeople]] = 0;
    ChoicetRentRent[[LoopOverPeriods]]       = ChoicetRentRent[[LoopOverPeriods]] + (1/NumOfPeople) //N;
    PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]] 
                                             = NotAHomeOwner;
    ];

  If[ChoicetSims[[LoopOverPeriods,LoopOverPeople]] == ChoiceRentBuy ,
    htSims[[LoopOverPeriods,LoopOverPeople]] = phi;
    HomeSaleProceeds[[LoopOverPeople]]       = 0;
    HomePurchCosts[[LoopOverPeople]]         = (b+DownPmtRatioGrid[[DebtRatioStateList[[LoopOverPeriods]]]]) phi;
    RentalCosts[[LoopOverPeople]]            = 0;
    HomesBoughtPerCapita[[LoopOverPeriods]]  = HomesBoughtPerCapita[[LoopOverPeriods]]+1/NumOfPeople;
    DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]] = DebtRatioStateList[[LoopOverPeriods]];
    dtSims[[LoopOverPeriods,LoopOverPeople]] = DebtRatioGrid[[DebtRatioStateList[[LoopOverPeriods]]]] * phi;
    ChoicetRentBuy[[LoopOverPeriods]]        = ChoicetRentBuy[[LoopOverPeriods]] + (1/NumOfPeople) //N;
    PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]] 
                                             = 0;
    ];

  If[ChoicetSims[[LoopOverPeriods,LoopOverPeople]] == ChoiceKeep    ,
    htSims[[LoopOverPeriods,LoopOverPeople]] = htSims[[LoopOverPeriods-1,LoopOverPeople]](1-delta)
                                               /(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods,LoopOverPeople]]);
    HomeSaleProceeds[[LoopOverPeople]]       = 0;
    HomePurchCosts[[LoopOverPeople]]         = 0;
    RentalCosts[[LoopOverPeople]]            = 0;
    DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]] = DebtRatioWhenBought[[LoopOverPeriods-1,LoopOverPeople]];
    dtSims[[LoopOverPeriods,LoopOverPeople]] = DebtRatioGrid[[DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]]]] 
                                               * htSims[[LoopOverPeriods,LoopOverPeople]];
    ChoicetKeep[[LoopOverPeriods]]           = ChoicetKeep[[LoopOverPeriods]] + (1/NumOfPeople) //N;
    PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]] 
                                             = PeriodsSinceLastHomePurchase[[LoopOverPeriods-1,LoopOverPeople]] + 1;
    PeriodsSinceLastHomePurchaseMean[[LoopOverPeriods]] =   PeriodsSinceLastHomePurchaseMean[[LoopOverPeriods]] 
                                                          + PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]]
    ];

(* 
% Note: we only calculate the periods since the last home purchase for people who are
% homeowners
*)

  If[ChoicetSims[[LoopOverPeriods,LoopOverPeople]] == ChoiceSellRent,
    htSims[[LoopOverPeriods,LoopOverPeople]] = hmin;
    HomeSaleProceeds[[LoopOverPeople]]       = ((1-DebtRatioGrid[[DebtRatioWhenBought[[LoopOverPeriods-1,LoopOverPeople]]]])-b)
                                               *htSims[[LoopOverPeriods-1,LoopOverPeople]](1-delta)/(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods,LoopOverPeople]]);
    HomePurchCosts[[LoopOverPeople]]         = 0;
    RentalCosts[[LoopOverPeople]]            = q lambda[[DebtRatioStateList[[LoopOverPeriods]]]] 
                                               *ztSims[[LoopOverPeriods,LoopOverPeople]];
    HomesSoldPerCapita[[LoopOverPeriods]]    = HomesSoldPerCapita[[LoopOverPeriods]]+1/NumOfPeople;
    DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]] = DebtRatioStateList[[LoopOverPeriods]];
    dtSims[[LoopOverPeriods,LoopOverPeople]] = 0;
    ChoicetSellRent[[LoopOverPeriods]]       = ChoicetSellRent[[LoopOverPeriods]] + (1/NumOfPeople) //N;
    PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]] 
                                             = NotAHomeOwner;
    ];
    
  If[ChoicetSims[[LoopOverPeriods,LoopOverPeople]] == ChoiceSellBuy,
    htSims[[LoopOverPeriods,LoopOverPeople]] = phi;
    HomeSaleProceeds[[LoopOverPeople]]       = ((1-DebtRatioGrid[[DebtRatioWhenBought[[LoopOverPeriods-1,LoopOverPeople]]]])-b) 
                                               *htSims[[LoopOverPeriods-1,LoopOverPeople]](1-delta)/(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods,LoopOverPeople]]);
    HomePurchCosts[[LoopOverPeople]]         = (b+DownPmtRatioGrid[[DebtRatioStateList[[LoopOverPeriods]]]]) phi;
    RentalCosts[[LoopOverPeople]]            = 0;
    HomesBoughtPerCapita[[LoopOverPeriods]]  = HomesBoughtPerCapita[[LoopOverPeriods]]+1/NumOfPeople;
    HomesSoldPerCapita[[LoopOverPeriods]]    = HomesSoldPerCapita[[LoopOverPeriods]]+1/NumOfPeople;
    DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]] = DebtRatioStateList[[LoopOverPeriods]];
    dtSims[[LoopOverPeriods,LoopOverPeople]] = DebtRatioGrid[[DebtRatioWhenBought[[LoopOverPeriods,LoopOverPeople]]]] * phi;
    ChoicetSellBuy[[LoopOverPeriods]]        = ChoicetSellBuy[[LoopOverPeriods]] + (1/NumOfPeople) //N;
    PeriodsSinceLastHomePurchase[[LoopOverPeriods,LoopOverPeople]] 
                                             = 0;
    ];
(* Print["End of person "<>ToString[LoopOverPeople]]; *)
,{LoopOverPeople,NumOfPeople}];  (* End of loop over people *)

HomeCarryingCosts = htSims[[LoopOverPeriods]]*(DebtRatioGrid[[DebtRatioWhenBought[[LoopOverPeriods]]]] (m[[aggstate[[LoopOverPeriods]]]])+n);
stSims[[LoopOverPeriods]] =  xtSims[[LoopOverPeriods]] 
                           - ctSims[[LoopOverPeriods]] 
                           + HomeSaleProceeds 
                           - HomePurchCosts 
                           - HomeCarryingCosts 
                           - RentalCosts;

savSims[[LoopOverPeriods]] =   etDraws[[LoopOverPeriods]] 
                             + (R[[aggstate[[LoopOverPeriods]]]]/(G[[LoopOverPeriods,aggstate[[LoopOverPeriods]]]] epDraws[[LoopOverPeriods]])-1)
                               *stSims[[LoopOverPeriods-1]]
                             - ctSims[[LoopOverPeriods]] - RentalCosts - HomeCarryingCosts;

StSims[[LoopOverPeriods]]  = stSims[[LoopOverPeriods]]*PermanentIncomeSims[[LoopOverPeriods]];
SavSims[[LoopOverPeriods]] = savSims[[LoopOverPeriods]]*PermanentIncomeSims[[LoopOverPeriods]];
HtSims[[LoopOverPeriods]]  = htSims[[LoopOverPeriods]]*PermanentIncomeSims[[LoopOverPeriods]];
DtSims[[LoopOverPeriods]]  = dtSims[[LoopOverPeriods]]*PermanentIncomeSims[[LoopOverPeriods]];

xtSimsMean[[LoopOverPeriods]]  = Mean[xtSims[[LoopOverPeriods]]];
savSimsMean[[LoopOverPeriods]] = Mean[savSims[[LoopOverPeriods]]];
stSimsMean[[LoopOverPeriods]]  = Mean[stSims[[LoopOverPeriods]]];
htSimsMean[[LoopOverPeriods]]  = Mean[htSims[[LoopOverPeriods]]];
ctSimsMean[[LoopOverPeriods]]  = Mean[ctSims[[LoopOverPeriods]]];
ztSimsMean[[LoopOverPeriods]]  = Mean[ztSims[[LoopOverPeriods]]];
dtSimsMean[[LoopOverPeriods]]  = Mean[dtSims[[LoopOverPeriods]]];

XtSimsMean[[LoopOverPeriods]]  = Mean[XtSims[[LoopOverPeriods]]];
SavSimsMean[[LoopOverPeriods]] = Mean[SavSims[[LoopOverPeriods]]];
StSimsMean[[LoopOverPeriods]]  = Mean[StSims[[LoopOverPeriods]]];
HtSimsMean[[LoopOverPeriods]]  = Mean[HtSims[[LoopOverPeriods]]];
CtSimsMean[[LoopOverPeriods]]  = Mean[CtSims[[LoopOverPeriods]]];
ZtSimsMean[[LoopOverPeriods]]  = Mean[ZtSims[[LoopOverPeriods]]];
DtSimsMean[[LoopOverPeriods]]  = Mean[DtSims[[LoopOverPeriods]]];
etDrawsMean[[LoopOverPeriods]] = Mean[etDraws[[LoopOverPeriods]]];
epDrawsMean[[LoopOverPeriods]] = Mean[epDraws[[LoopOverPeriods]]];

NumOfHomeOwners = (ChoicetRentBuy[[LoopOverPeriods]] + ChoicetKeep[[LoopOverPeriods]] + ChoicetSellBuy[[LoopOverPeriods]])
                  *NumOfPeople;

(* % Changed for the case where there are no homeowners *)
PeriodsSinceLastHomePurchaseMean[[LoopOverPeriods]] 
                               = If[NumOfHomeOwners>0,PeriodsSinceLastHomePurchaseMean[[LoopOverPeriods]]/NumOfHomeOwners,0];


DebtRatioWhenBoughtMean[[LoopOverPeriods]]   = Mean[DebtRatioWhenBought[[LoopOverPeriods]]];
PermanentIncomeMean[[LoopOverPeriods]]       = Mean[PermanentIncomeSims[[LoopOverPeriods]]];
Income[[LoopOverPeriods]]                    = Mean[PermanentIncomeSims[[LoopOverPeriods]] etDraws[[LoopOverPeriods]]];

(* % Start of new part *)

If[LoopOverPeriods+1>Last[StartOfLifePart],
   (* then *)
   LifePartPos = NumOfLifeParts,
   (* else *)
   LifePartPos =
FirstElementGreaterThan[StartOfLifePart,LoopOverPeriods+1]-1
]; (* end If[] *)

AnnuityIncome[[LoopOverPeriods]] = 
AggEmpState[LoopOverPeriods] . AnnuityIncomeByAggEmpState[[LifePartPos]];

(*
Print["Life part "<>ToString[LifePartPos]];
Print["Annuity Income is  "<>ToString[AnnuityIncome[[LoopOverPeriods]]]];
*)

(* % End of new part *)

IncomeOverAnnuityIncome[[LoopOverPeriods]]   = Income[[LoopOverPeriods]]/
                                                 (PermanentIncomeMean[[LoopOverPeriods]] AnnuityIncome[[LoopOverPeriods]]);
ExpectedJobLossRisk[[LoopOverPeriods]]       = ExpectedJobLossRiskByAggEmpState[LoopOverPeriods];
UnemploymentRate[[LoopOverPeriods]]          = 1- EmploymentStatusCounts[[LoopOverPeriods,EmpStateEmployed]]/NumOfPeople //N;


LastPeriodSimulated= LoopOverPeriods;

(* Print["Almost done with loop"]; *)

(* % Keep every Nth period, and also keep any selected PEriodsToKeep *)

If[LoopOverPeriods > 3, 
  (* then *)
  If[Mod[LoopOverPeriods-2,KeepEveryNthPeriod] != 0,
    If[Length[Position[PeriodsToKeep,LoopOverPeriods-2]] == 0, 
      (* if it's not a period we want to keep, erase it *)
      ClearPeriodsFromTo[LoopOverPeriods-2,LoopOverPeriods-2];
      ];
    ];
  ];
,{LoopOverPeriods,StartPeriod,EndPeriod}];

(* % End of the Do loop for KeepSimulatingPeriods *)


(* % Calculate log difference growth rates for each period in the simulation *)

CtGrowth = YtGrowth = DtGrowth = ctSimsMean;
Do[
CtGrowth[[i]]  = Log[CtSimsMean[[i]]  /CtSimsMean[[i-1]]];
YtGrowth[[i]]  = Log[etDrawsMean[[i]] PermanentIncomeMean[[i]]  /(etDrawsMean[[i-1]] PermanentIncomeMean[[i-1]])];
(* DtGrowth[[i]] = Log[DtSimsMean[[i]] /DtSimsMean[[i-1]]];  *)
,{i,2,LastPeriodSimulated}
];

]; 

(* End of KeepSimulatingFromTo *)



ClearAll[LP];
LP[ListOfMeans_] := ListPlot[
                      Transpose[
                        {Table[i,{i,2,LastPeriodSimulated}]
                        ,Take[ListOfMeans,{2,LastPeriodSimulated}]}]
                      ,PlotRange->All,PlotJoined->True];

ClearAll[LPSeriesFromTo];
LPSeriesFromTo[ListOfMeans_,From_,To_,SeriesLabel_:"",TickList_:Automatic,PlotStyleChoice_:Automatic,CycleLines_:True] := Block[{},
    DataSlice = Take[ListOfMeans,{From,To}];
    VertMin = Min[DataSlice];
    VertMax = Max[DataSlice];
    VertGap = VertMax - VertMin;
    VertMinPlot = VertMin - .2 VertGap;
    VertMaxPlot = VertMax + .2 VertGap;
    SeriesPlot = ListPlot[
       Transpose[
         {Table[i,{i,From,To}]
         ,Take[ListOfMeans,{From,To}]}
       ] (* End Transpose *)
       ,PlotJoined->True
       ,DisplayFunction->Identity
       ,PlotStyle->PlotStyleChoice
       ,AxesOrigin->{From,VertMinPlot}
       ,PlotRange->{Automatic,{VertMinPlot,VertMaxPlot}}
       ,PlotLabel->SeriesLabel
       ,Ticks->TickList
     ]; (* End SeriesPlot *)
     If[CycleLines == True,
       (* then create plots containing the lines demarcating the cyclical changes *)
         CyclePlot = PlotRecessions[1.4 VertGap,VertMinPlot ,From,To];
         RecoveryPlot = PlotRecovery[1.4 VertGap,VertMinPlot,From,To];
         Show[Graphics[{CyclePlot,RecoveryPlot}],SeriesPlot
             ,DisplayFunction->$DisplayFunction
             ,AxesOrigin->{From,VertMinPlot}
             ,PlotRange->{Automatic,{VertMinPlot,VertMaxPlot}}
             ,PlotLabel->SeriesLabel
             ,Ticks->TickList
             ,TextStyle->{FontFamily->"Times"}
             ,TextStyle->{FontSize->12}
             ,Axes->True],
       (* else just do the plot without the cyclical lines *)  
         Show[SeriesPlot]]
]; (* End LPSeriesFromTo *)

LPSeriesFromTo::usage = "LPSeriesFromTo[ListOfMeans,From,To,SeriesLabel->LabelInQuotes,TickList->Automatic,PlotStyleChoice->Automatic,CycleLines->True]"


ClearAll[LPSeriesFrom];
LPSeriesFrom[ListOfMeans_,From_] := 
    ListPlot[
       Transpose[
         {Table[i,{i,From,LastPeriodSimulated}]
         ,Take[ListOfMeans,{From,LastPeriodSimulated}]}
       ] (* End Transpose *)
     ,PlotRange->All,PlotJoined->True]; (* End LPSeriesFrom *)


MultiplyNumOfPeopleByInPeriod[MultiplicationFactor_,Period_] := 
Block[{},
  Print["Adding Period "<>ToString[Period+1]];
  EmploymentStatus[[Period+1]]    = Flatten[Table[EmploymentStatus[[Period]],{MultiplicationFactor}]];
  xtSims[[Period+1]]              = Flatten[Table[xtSims[[Period]] ,{MultiplicationFactor}]];
  dtSims[[Period+1]]              = Flatten[Table[dtSims[[Period]] ,{MultiplicationFactor}]];
  ctSims[[Period+1]]              = Flatten[Table[ctSims[[Period]] ,{MultiplicationFactor}]];
  ztSims[[Period+1]]              = Flatten[Table[ztSims[[Period]] ,{MultiplicationFactor}]];
  stSims[[Period+1]]              = Flatten[Table[stSims[[Period]] ,{MultiplicationFactor}]];
  htSims[[Period+1]]              = Flatten[Table[htSims[[Period]] ,{MultiplicationFactor}]];
  savSims[[Period+1]]             = Flatten[Table[savSims[[Period]],{MultiplicationFactor}]];
  XtSims[[Period+1]]              = Flatten[Table[XtSims[[Period]] ,{MultiplicationFactor}]];
  DtSims[[Period+1]]              = Flatten[Table[DtSims[[Period]] ,{MultiplicationFactor}]];
  CtSims[[Period+1]]              = Flatten[Table[CtSims[[Period]] ,{MultiplicationFactor}]];
  ZtSims[[Period+1]]              = Flatten[Table[ZtSims[[Period]] ,{MultiplicationFactor}]];
  StSims[[Period+1]]              = Flatten[Table[StSims[[Period]] ,{MultiplicationFactor}]];
  HtSims[[Period+1]]              = Flatten[Table[HtSims[[Period]] ,{MultiplicationFactor}]];
  SavSims[[Period+1]]             = Flatten[Table[SavSims[[Period]],{MultiplicationFactor}]];
  PeriodsSinceLastHomePurchase[[Period+1]] = Flatten[Table[PeriodsSinceLastHomePurchase[[Period]],{MultiplicationFactor}]];
  etVarsPopulation[[Period+1]]    = Flatten[Table[etVarsPopulation[[Period]],{MultiplicationFactor}]];
  epVarsPopulation[[Period+1]]    = Flatten[Table[epVarsPopulation[[Period]],{MultiplicationFactor}]];
  PermanentIncomeSims[[Period+1]] = Flatten[Table[PermanentIncomeSims[[Period]] ,{MultiplicationFactor}]];
  etDraws[[Period+1]]             = Flatten[Table[etDraws[[Period]],{MultiplicationFactor}]];
  epDraws[[Period+1]]             = Flatten[Table[epDraws[[Period]],{MultiplicationFactor}]];
  ChoicetSims[[Period+1]]         = Flatten[Table[ChoicetSims[[Period]],{MultiplicationFactor}]];
  DebtRatioWhenBought[[Period+1]] = Flatten[Table[DebtRatioWhenBought[[Period]],{MultiplicationFactor}]];
  xtSimsMean[[Period+1]]          = xtSimsMean[[Period]];  
  stSimsMean[[Period+1]]          = stSimsMean[[Period]];  
  htSimsMean[[Period+1]]          = htSimsMean[[Period]];  
  ctSimsMean[[Period+1]]          = ctSimsMean[[Period]];  
  ztSimsMean[[Period+1]]          = ztSimsMean[[Period]];  
  dtSimsMean[[Period+1]]          = dtSimsMean[[Period]];  
  savSimsMean[[Period+1]]         = savSimsMean[[Period]];  
  XtSimsMean[[Period+1]]          = XtSimsMean[[Period]];  
  StSimsMean[[Period+1]]          = StSimsMean[[Period]];  
  HtSimsMean[[Period+1]]          = HtSimsMean[[Period]];  
  CtSimsMean[[Period+1]]          = CtSimsMean[[Period]];  
  ZtSimsMean[[Period+1]]          = ZtSimsMean[[Period]];  
  DtSimsMean[[Period+1]]          = DtSimsMean[[Period]];  
  SavSimsMean[[Period+1]]         = SavSimsMean[[Period]];  
  etDrawsMean[[Period+1]]         = etDrawsMean[[Period]]; 
  epDrawsMean[[Period+1]]         = epDrawsMean[[Period]]; 
  ChoicetRentRent[[Period+1]]     = ChoicetRentRent[[Period]];
  ChoicetRentBuy[[Period+1]]      = ChoicetRentBuy[[Period]];
  ChoicetSellRent[[Period+1]]     = ChoicetSellRent[[Period]];
  ChoicetKeep[[Period+1]]         = ChoicetKeep[[Period]];
  ChoicetSellBuy[[Period+1]]      = ChoicetSellBuy[[Period]];
  DebtRatioWhenBoughtMean[[Period+1]] = DebtRatioWhenBoughtMean[[Period]];
  PeriodsSinceLastHomePurchaseMean[[Period+1]] = PeriodsSinceLastHomePurchaseMean[[Period]];
  HomesBoughtPerCapita[[Period+1]]      = HomesBoughtPerCapita[[Period]];
  HomesSoldPerCapita[[Period+1]]        = HomesSoldPerCapita[[Period]];
  Income[[Period+1]]                    = Income[[Period]];
  AnnuityIncome[[Period+1]]             = AnnuityIncome[[Period]];
  IncomeOverAnnuityIncome[[Period+1]]   = IncomeOverAnnuityIncome[[Period]];
  ExpectedJobLossRisk[[Period+1]]       = ExpectedJobLossRisk[[Period]];
  UnemploymentRate[[Period+1]]          = UnemploymentRate[[Period]];
  EmploymentStatusCounts[[Period+1]]    = EmploymentStatusCounts[[Period]] * MultiplicationFactor;
  PermanentIncomeMean[[Period+1]]    = PermanentIncomeMean[[Period]];
];
  
  
Clear[SaveSims];
SaveSims[filename_]:= 
Block[{},
  DeleteFile[filename];
  Save[filename
           ,xtSims
           ,ctSims
           ,ztSims
           ,stSims
           ,htSims
           ,dtSims
           ,savSims
           ,XtSims
           ,CtSims
           ,ZtSims
           ,StSims
           ,HtSims
           ,DtSims
           ,SavSims
           ,ChoicetSims
           ,PermanentIncomeSims
           ,DebtRatioWhenBought
           ,etDraws
           ,epDraws
           ,aggstate
           ,DebtRatioStateList
           ,LastPeriodSimulated
           ,DebtRatioWhenBoughtMean
           ,xtSimsMean
           ,ctSimsMean
           ,ztSimsMean
           ,stSimsMean
           ,htSimsMean
           ,savSimsMean
           ,dtSimsMean
           ,XtSimsMean
           ,CtSimsMean
           ,ZtSimsMean
           ,StSimsMean
           ,HtSimsMean
           ,SavSimsMean
           ,DtSimsMean
           ,aggstate,etDrawsMean,epDrawsMean
           ,PermanentIncomeMean
           ,HomesBoughtPerCapita
           ,HomesSoldPerCapita
           ,KeepEveryNthPeriod
           ,ChoicetRentRent
           ,ChoicetRentBuy
           ,ChoicetSellRent
           ,ChoicetKeep
           ,ChoicetSellBuy
           ,etVarsPopulation
           ,epVarsPopulation
           ,PeriodsToKeep
           ,KeepEveryNthPeriod
           ,PeriodsSinceLastHomePurchase
           ,PeriodsSinceLastHomePurchaseMean
           ,HomesBoughtPerCapita
           ,HomesSoldPerCapita
           ,StateVars
           ,Income
           ,AnnuityIncome
           ,IncomeOverAnnuityIncome
           ,ExpectedJobLossRisk
           ,UnemploymentRate
           ,CtGrowth
           ,DtGrowth
           ,YtGrowth
           ,EmploymentStatus
           ,EmploymentStatusCounts
           ,delta
           ,gamma
           ,G
           ,epVals
           ,epProb
           ,etVals
           ,etProb
           ,NumOfAggStates
           ,NumOfEmpStates
           ,NumOfDebtRatios
           ,AggStateTransitionMatrix
           ,EmpStateTransitionMatrix
           ,CumEmpStateTransitionMatrix
           ,EmpStateProb
           ,CumEmpStateNext
           ,PeriodsToKeep
    ];  
];

Clear[SaveSimsMed];
SaveSimsMed[filename_]:= 
Block[{},
  DeleteFile[filename];
  Save[filename
           ,xtSims
           ,ctSims
           ,ztSims
           ,stSims
           ,htSims
           ,dtSims
           ,savSims
           ,ChoicetSims,PermanentIncomeSims
           ,DebtRatioWhenBought
           ,aggstate
           ,DebtRatioStateList
           ,LastPeriodSimulated
           ,DebtRatioWhenBoughtMean
           ,xtSimsMean
           ,ctSimsMean
           ,ztSimsMean
           ,stSimsMean
           ,htSimsMean
           ,savSimsMean
           ,dtSimsMean
           ,XtSimsMean
           ,CtSimsMean
           ,ZtSimsMean
           ,StSimsMean
           ,HtSimsMean
           ,SavSimsMean
           ,DtSimsMean
           ,etDrawsMean,epDrawsMean
           ,PermanentIncomeMean
           ,HomesBoughtPerCapita
           ,HomesSoldPerCapita
           ,KeepEveryNthPeriod
           ,ChoicetRentRent
           ,ChoicetRentBuy
           ,ChoicetSellRent
           ,ChoicetKeep
           ,ChoicetSellBuy
           ,etVarsPopulation
           ,epVarsPopulation
           ,PeriodsToKeep
           ,KeepEveryNthPeriod
           ,PeriodsSinceLastHomePurchase
           ,PeriodsSinceLastHomePurchaseMean
           ,HomesBoughtPerCapita
           ,HomesSoldPerCapita
           ,StateVars
           ,Income
           ,AnnuityIncome
           ,IncomeOverAnnuityIncome
           ,ExpectedJobLossRisk
           ,UnemploymentRate
           ,CtGrowth
           ,DtGrowth
           ,YtGrowth
           ,EmploymentStatus
           ,EmploymentStatusCounts
           ,delta
           ,gamma
           ,G
           ,epVals
           ,epProb
           ,etVals
           ,etProb
           ,NumOfAggStates
           ,NumOfEmpStates
           ,NumOfDebtRatios
           ,AggStateTransitionMatrix
           ,EmpStateTransitionMatrix
           ,CumEmpStateTransitionMatrix
           ,EmpStateProb
           ,CumEmpStateNext
           ,PeriodsToKeep
    ];  
];

Clear[SaveSimsSmall];
SaveSimsSmall[filename_]:= 
Block[{},
(*  NumOfPeople = Length[htSims[[LastPeriodSimulated]]];*)
  DeleteFile[filename];
  Save[filename,
          ,aggstate
          ,DebtRatioStateList
          ,LastPeriodSimulated
          ,xtSimsMean,ctSimsMean,ztSimsMean,stSimsMean,htSimsMean,aggstate,etDrawsMean,epDrawsMean,dtSimsMean
          ,XtSimsMean
          ,CtSimsMean
          ,ZtSimsMean
          ,StSimsMean
          ,HtSimsMean
          ,SavSimsMean
          ,DtSimsMean
          ,etVarsPopulation
          ,epVarsPopulation
          ,DebtRatioWhenBoughtMean
          ,PermanentIncomeMean
          ,HomesBoughtPerCapita
          ,HomesSoldPerCapita
          ,KeepEveryNthPeriod
          ,ChoicetRentRent
          ,ChoicetRentBuy
          ,ChoicetSellRent
          ,ChoicetKeep
          ,ChoicetSellBuy
          ,PeriodsSinceLastHomePurchaseMean
          ,HomesBoughtPerCapita
          ,HomesSoldPerCapita
          ,savSimsMean
          ,Income
          ,AnnuityIncome
          ,IncomeOverAnnuityIncome
          ,ExpectedJobLossRisk
          ,UnemploymentRate
          ,CtGrowth
          ,DtGrowth
          ,YtGrowth
          ,EmploymentStatusCounts
          ,delta
          ,gamma
          ,G
          ,epVals
          ,epProb
          ,etVals
          ,etProb
          ,NumOfAggStates
          ,NumOfEmpStates
          ,NumOfDebtRatios
          ,AggStateTransitionMatrix
          ,EmpStateTransitionMatrix
          ,CumEmpStateTransitionMatrix
          ,EmpStateProb
          ,CumEmpStateNext
          ,PeriodsToKeep
          ,NumOfPeople
  ];
];

Clear[MakeTimeSeriesDataFile];
MakeTimeSeriesDataFile[filename_,FirstPeriodToSave_,LastPeriodToSave_] := 
Block[{},
  DeleteFile[filename];
  OutputObject = OpenWrite[filename,PageWidth->Infinity];
  SetOptions[OutputObject,PageWidth->Infinity];
  OutputList = 
      Take[
        Transpose[
         {
          xtSimsMean
         ,stSimsMean
         ,htSimsMean
         ,ctSimsMean
         ,ztSimsMean
         ,dtSimsMean
         ,XtSimsMean
         ,CtSimsMean
         ,ZtSimsMean
         ,StSimsMean
         ,HtSimsMean
         ,SavSimsMean
         ,DtSimsMean
         ,etDrawsMean
         ,epDrawsMean
         ,DebtRatioWhenBoughtMean
         ,PermanentIncomeMean
         ,PeriodsSinceLastHomePurchaseMean
         ,ChoicetRentRent
         ,ChoicetRentBuy
         ,ChoicetSellRent
         ,ChoicetKeep
         ,ChoicetSellBuy
         ,HomesBoughtPerCapita
         ,HomesSoldPerCapita
         ,savSimsMean
         ,Income
         ,AnnuityIncome
         ,IncomeOverAnnuityIncome
         ,ExpectedJobLossRisk
         ,UnemploymentRate
         ,CtGrowth
         ,DtGrowth
         ,YtGrowth
         }]                     (* End Transpose           *)
       ,{FirstPeriodToSave, LastPeriodToSave}
       ] //N;                        (* End Take                *)

    FormattedOutput = TableForm[Map[FortranForm,OutputList,{Length[OutputList]}],TableSpacing->{0,3}];
    Write[OutputObject,FormattedOutput // OutputForm];
    Close[filename];
]                               (* End Block               *)



(*

This file merges the results from multiple simulations into
a singe dataset

*)

Merge[file1_,file2_,newfile_] := Block[{},
Get[file1];
ClearPeriodsFromTo[2,LastPeriodSimulated-2];
NumOfPeople1 = NumOfPeople;

ListOfVars = {"xtSimsMean","ctSimsMean","ztSimsMean","stSimsMean","htSimsMean","dtSimsMean","savSimsMean",
"XtSimsMean","CtSimsMean","ZtSimsMean","StSimsMean","HtSimsMean","DtSimsMean","SavSimsMean",
"DebtRatioWhenBoughtMean","PermanentIncomeMean","PeriodsSinceLastHomePurchaseMean",
"etDrawsMean","epDrawsMean",
"HomesBoughtPerCapita","HomesSoldPerCapita","KeepEveryNthPeriod","ChoicetRentRent"
,"ChoicetRentBuy","ChoicetSellRent","ChoicetKeep","ChoicetSellBuy"
,"PeriodsSinceLastHomePurchaseMean","HomesBoughtPerCapita","HomesSoldPerCapita"
,"savSimsMean","Income","AnnuityIncome","IncomeOverAnnuityIncome"
,"ExpectedJobLossRisk","UnemploymentRate","CtGrowth","DtGrowth"
,"YtGrowth","EmploymentStatusCounts"};

(*,"delta"
,"gamma","G","epVals","epProb","etVals","etProb","NumOfAggStates"
,"NumOfEmpStates","NumOfDebtRatios","AggStateTransitionMatrix","EmpStateTransitionMatrix"
,"CumEmpStateTransitionMatrix","EmpStateProb","CumEmpStateNext","PeriodsToKeep";
*)

Do[
ToExpression[ListOfVars[[i]]<>"tmp = "<>ListOfVars[[i]]];
,{i,Length[ListOfVars]}];

Get[file2];

NumOfPeople2 = NumOfPeople;


TotalPeople = NumOfPeople1 + NumOfPeople2;
ClearPeriodsFromTo[2,LastPeriodSimulated-2];

Do[
DoingWhat = 
ListOfVars[[i]]<>"tmp2 = "<>ListOfVars[[i]]<>"tmp * "
<>ToString[NumOfPeople1/TotalPeople //N]
<>"+"<>ListOfVars[[i]]
<>"*"<>ToString[NumOfPeople2/TotalPeople //N];
Print[DoingWhat];
ToExpression[DoingWhat];
,{i,Length[ListOfVars]}];



Do[
ToExpression[ListOfVars[[i]]<>"="<>ListOfVars[[i]]<>"tmp2"];
,{i,Length[ListOfVars]}];


NumOfPeople = TotalPeople;

SaveSimsSmall[newfile];

];

