(* 
% Assumes you have already constructed the list of x, s, and h points
% Creates the InStateGrid table containing all combinations of the state
% variables {cash-on-hand, homeownership, agg state, debt ratio when bought, 
% debt ratio on new homes, employment state}
% Creates the OutStateGrid table containing all combinations of the state
% variables {savings, homeownership, agg state, debt ratio when bought, 
% debt ratio on new homes, employment state}
*)

Print["xgrid: "<>ToString[xgrid]];
Print["sgrid: "<>ToString[sgrid]];
Print["hgrid: "<>ToString[hgrid]];

InStateGrid = Table[{},{LifeLength}];

(*
Create a baseline set of grid points spanning the regions defined by xgrid, hgrid, sgrid,
and the possible values of AggState and DebtRatioState
*)
InStateGridBaseline = {};
Do[
Do[InStateGridBaseline 
  = Append[InStateGridBaseline,{xgrid[[i]],hgrid[[j]],LoopOverAggStates,k,l,m}];
,{i,Length[xgrid]},{j,Length[hgrid]},{k,Length[DebtRatioGrid]},{l,Length[DebtRatioGrid]},{m,NumOfEmpStates}];
,{LoopOverAggStates,NumOfAggStates}];

(* % Set the last period to the InStateGridBaseline *)
InStateGrid[[LifeLength]] = InStateGridBaseline; 
(*
If[LowMem == False, (* Fill in for all periods of life *)
    Do[InStateGrid[[LoopOverLifePosn]]=InStateGrid[[LoopOverLifePosn+1]]
    ,{LoopOverLifePosn,LifeLength-1,1,-1}];
];
*)

(* % Do the same thing for the OutStateGrid *)
OutStateGrid = Table[{},{LifeLength}];

OutStateGridBaseline = {}; (* EmptyArrayLifeLength; *)
Do[
  Do[OutStateGridBaseline
      = Append[OutStateGridBaseline,{sgrid[[i]],hgrid[[j]],LoopOverAggStates,k,l,m}];
    ,{i,Length[sgrid]},{j,Length[hgrid]},{k,Length[DebtRatioGrid]},{l,Length[DebtRatioGrid]},{m,NumOfEmpStates}];
  ,{LoopOverAggStates,NumOfAggStates}
];

(* % Set the last period to the OutStateGridBaseline *)
OutStateGrid[[LifeLength]] = OutStateGridBaseline;
(*
If[LowMem == False,  (* Fill in for all periods of life *)
    Do[OutStateGrid[[LoopOverLifePosn]]=OutStateGrid[[LoopOverLifePosn+1]]
      ,{LoopOverLifePosn,LifeLength-1,1,-1}];
];
*)
